@@ -22,8 +22,27 @@ source $(dirname $0)/../vendor/knative.dev/test-infra/scripts/library.sh
 
 cd "${REPO_ROOT_DIR}"
 
+# The list of dependencies that we track at HEAD and periodically
+# float forward in this repository.
+FLOATING_DEPS=(
+  "knative.dev/pkg"
+  "knative.dev/test-infra"
+)
+
+# Parse flags to determine any we should pass to dep.
+DEP_FLAGS=()
+while [[ $# -ne 0 ]]; do
+  parameter=$1
+  case ${parameter} in
+    --upgrade) DEP_FLAGS=( -update ${FLOATING_DEPS[@]} ) ;;
+    *) abort "unknown option ${parameter}" ;;
+  esac
+  shift
+done
+readonly DEP_FLAGS
+
 # Ensure we have everything we need under vendor/
-dep ensure
+dep ensure ${DEP_FLAGS[@]}
 
 find vendor/ -name 'OWNERS' -delete
 find vendor/ -name '*_test.go' -delete
